@@ -18,13 +18,13 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "encryptedpacketsocket.h"
-#include <errno.h>
-#include <util/sha1hash.h>
-#include <util/log.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/socket.h>
 #include <QtGlobal>
+#include <errno.h>
+#include <stdlib.h>
+#include <sys/socket.h>
+#include <sys/types.h>
+#include <util/log.h>
+#include <util/sha1hash.h>
 #ifndef Q_WS_WIN
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
@@ -32,23 +32,22 @@
 #else
 #define IPTOS_THROUGHPUT 0x08
 #endif
-#include <netinet/tcp.h>
-#include <net/socketmonitor.h>
-#include <util/functions.h>
 #include "rc4encryptor.h"
+#include <net/socketmonitor.h>
+#include <netinet/tcp.h>
+#include <util/functions.h>
 
 using namespace bt;
 using namespace net;
 
 namespace mse
 {
-
 Uint8 EncryptedPacketSocket::tos = IPTOS_THROUGHPUT;
 
-EncryptedPacketSocket::EncryptedPacketSocket(int ip_version) :
-    net::PacketSocket(true, ip_version),
-    enc(0),
-    monitored(false)
+EncryptedPacketSocket::EncryptedPacketSocket(int ip_version)
+    : net::PacketSocket(true, ip_version)
+    , enc(0)
+    , monitored(false)
 {
     sock->setBlocking(false);
     sock->setTOS(tos);
@@ -57,10 +56,10 @@ EncryptedPacketSocket::EncryptedPacketSocket(int ip_version) :
     reinserted_data_read = 0;
 }
 
-EncryptedPacketSocket::EncryptedPacketSocket(int fd, int ip_version) :
-    net::PacketSocket(fd, ip_version),
-    enc(0),
-    monitored(false)
+EncryptedPacketSocket::EncryptedPacketSocket(int fd, int ip_version)
+    : net::PacketSocket(fd, ip_version)
+    , enc(0)
+    , monitored(false)
 {
     sock->setBlocking(false);
     sock->setTOS(tos);
@@ -69,10 +68,10 @@ EncryptedPacketSocket::EncryptedPacketSocket(int fd, int ip_version) :
     reinserted_data_read = 0;
 }
 
-EncryptedPacketSocket::EncryptedPacketSocket(net::SocketDevice* sd) :
-    net::PacketSocket(sd),
-    enc(0),
-    monitored(false)
+EncryptedPacketSocket::EncryptedPacketSocket(net::SocketDevice *sd)
+    : net::PacketSocket(sd)
+    , enc(0)
+    , monitored(false)
 {
     sd->setBlocking(false);
     sd->setTOS(tos);
@@ -86,23 +85,21 @@ EncryptedPacketSocket::~EncryptedPacketSocket()
     if (monitored)
         stopMonitoring();
 
-    delete [] reinserted_data;
+    delete[] reinserted_data;
     delete enc;
 }
 
-void EncryptedPacketSocket::startMonitoring(net::SocketReader* rdr)
+void EncryptedPacketSocket::startMonitoring(net::SocketReader *rdr)
 {
     setReader(rdr);
     SocketMonitor::instance().add(this);
     monitored = true;
     if (reinserted_data) {
         if (enc)
-            enc->decrypt(reinserted_data + reinserted_data_read,
-                         reinserted_data_size - reinserted_data_read);
+            enc->decrypt(reinserted_data + reinserted_data_read, reinserted_data_size - reinserted_data_read);
 
-        rdr->onDataReady(reinserted_data + reinserted_data_read,
-                         reinserted_data_size - reinserted_data_read);
-        delete [] reinserted_data;
+        rdr->onDataReady(reinserted_data + reinserted_data_read, reinserted_data_size - reinserted_data_read);
+        delete[] reinserted_data;
         reinserted_data = 0;
         reinserted_data_size = 0;
     }
@@ -115,12 +112,12 @@ void EncryptedPacketSocket::stopMonitoring()
     rdr = 0;
 }
 
-Uint32 EncryptedPacketSocket::sendData(const Uint8* data, Uint32 len)
+Uint32 EncryptedPacketSocket::sendData(const Uint8 *data, Uint32 len)
 {
     if (enc) {
         // we need to make sure all data is sent because of the encryption
         Uint32 ds = 0;
-        const Uint8* ed = enc->encrypt(data, len);
+        const Uint8 *ed = enc->encrypt(data, len);
         while (sock->ok() && ds < len) {
             Uint32 ret = sock->send(ed + ds, len - ds);
             ds += ret;
@@ -139,14 +136,14 @@ Uint32 EncryptedPacketSocket::sendData(const Uint8* data, Uint32 len)
     }
 }
 
-Uint32 EncryptedPacketSocket::readData(Uint8* buf, Uint32 len)
+Uint32 EncryptedPacketSocket::readData(Uint8 *buf, Uint32 len)
 {
     Uint32 ret2 = 0;
     if (reinserted_data) {
         Uint32 tr = reinserted_data_size - reinserted_data_read;
         if (tr < len) {
             memcpy(buf, reinserted_data + reinserted_data_read, tr);
-            delete [] reinserted_data;
+            delete[] reinserted_data;
             reinserted_data = 0;
             reinserted_data_size = reinserted_data_read = 0;
             ret2 = tr;
@@ -176,7 +173,7 @@ Uint32 EncryptedPacketSocket::bytesAvailable() const
 {
     Uint32 ba = sock->bytesAvailable();
     if (reinserted_data_size - reinserted_data_read > 0)
-        return  ba + (reinserted_data_size - reinserted_data_read);
+        return ba + (reinserted_data_size - reinserted_data_read);
     else
         return ba;
 }
@@ -186,7 +183,7 @@ void EncryptedPacketSocket::close()
     sock->close();
 }
 
-bool EncryptedPacketSocket::connectTo(const QString & ip, Uint16 port)
+bool EncryptedPacketSocket::connectTo(const QString &ip, Uint16 port)
 {
     // do a safety check
     if (ip.isNull() || ip.length() == 0)
@@ -195,7 +192,7 @@ bool EncryptedPacketSocket::connectTo(const QString & ip, Uint16 port)
     return connectTo(net::Address(ip, port));
 }
 
-bool EncryptedPacketSocket::connectTo(const net::Address & addr)
+bool EncryptedPacketSocket::connectTo(const net::Address &addr)
 {
     // we don't wanna block the current thread so set non blocking
     sock->setBlocking(false);
@@ -206,7 +203,7 @@ bool EncryptedPacketSocket::connectTo(const net::Address & addr)
     return false;
 }
 
-void EncryptedPacketSocket::initCrypt(const bt::SHA1Hash & dkey, const bt::SHA1Hash & ekey)
+void EncryptedPacketSocket::initCrypt(const bt::SHA1Hash &dkey, const bt::SHA1Hash &ekey)
 {
     delete enc;
     enc = new RC4Encryptor(dkey, ekey);
@@ -238,19 +235,19 @@ net::Address EncryptedPacketSocket::getRemoteAddress() const
     return sock->getPeerName();
 }
 
-void EncryptedPacketSocket::setRC4Encryptor(RC4Encryptor* e)
+void EncryptedPacketSocket::setRC4Encryptor(RC4Encryptor *e)
 {
     delete enc;
     enc = e;
 }
 
-void EncryptedPacketSocket::reinsert(const Uint8* d, Uint32 size)
+void EncryptedPacketSocket::reinsert(const Uint8 *d, Uint32 size)
 {
-//      Out() << "Reinsert : " << size << endl;
+    //      Out() << "Reinsert : " << size << endl;
     Uint32 off = 0;
     if (reinserted_data) {
         off = reinserted_data_size;
-        reinserted_data = (Uint8*)realloc(reinserted_data, reinserted_data_size + size);
+        reinserted_data = (Uint8 *)realloc(reinserted_data, reinserted_data_size + size);
         reinserted_data_size += size;
     } else {
         reinserted_data = new Uint8[size];
@@ -269,7 +266,7 @@ bool EncryptedPacketSocket::connectSuccesFull() const
     return sock->connectSuccesFull();
 }
 
-void EncryptedPacketSocket::setRemoteAddress(const net::Address & addr)
+void EncryptedPacketSocket::setRemoteAddress(const net::Address &addr)
 {
     sock->setRemoteAddress(addr);
 }
@@ -280,7 +277,7 @@ void EncryptedPacketSocket::preProcess(Packet::Ptr packet)
         enc->encryptReplace(packet->getData(), packet->getDataLength());
 }
 
-void EncryptedPacketSocket::postProcess(Uint8* data, Uint32 size)
+void EncryptedPacketSocket::postProcess(Uint8 *data, Uint32 size)
 {
     if (enc)
         enc->decrypt(data, size);
