@@ -18,9 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include "speed.h"
+#include <util/functions.h>
 #include <util/log.h>
 #include <util/timer.h>
-#include <util/functions.h>
 
 using namespace bt;
 
@@ -28,12 +28,15 @@ namespace net
 {
 const Uint64 SPEED_INTERVAL = 5000;
 
-Speed::Speed() : rate(0), bytes(0)
-{}
-
+Speed::Speed()
+    : rate(0)
+    , bytes(0)
+{
+}
 
 Speed::~Speed()
-{}
+{
+}
 
 void Speed::onData(Uint32 b, bt::TimeStamp ts)
 {
@@ -45,7 +48,7 @@ void Speed::update(bt::TimeStamp now)
 {
     auto i = dlrate.begin();
     while (i != dlrate.end()) {
-        QPair<Uint32, TimeStamp> & p = *i;
+        QPair<Uint32, TimeStamp> &p = *i;
         if (now - p.second > SPEED_INTERVAL || now < p.second) {
             if (bytes >= p.first) // make sure we don't wrap around
                 bytes -= p.first; // subtract bytes
@@ -69,7 +72,7 @@ void Speed::update(bt::TimeStamp now)
         rate = 0;
     } else {
         //  Out() << "bytes = " << bytes << " d = " << d << endl;
-        rate =  bytes / (SPEED_INTERVAL / 1000);
+        rate = bytes / (SPEED_INTERVAL / 1000);
     }
 }
 
